Index: Source/core/accessibility/AXNodeObject.cpp |
diff --git a/Source/core/accessibility/AXNodeObject.cpp b/Source/core/accessibility/AXNodeObject.cpp |
index 76381e162810bd626d81db51b243b4e1d33209e3..02577cdc208e00d7afab565f26c6247c7cfe63c3 100644 |
--- a/Source/core/accessibility/AXNodeObject.cpp |
+++ b/Source/core/accessibility/AXNodeObject.cpp |
@@ -1467,13 +1467,8 @@ HTMLLabelElement* AXNodeObject::labelElementContainer() const |
if (isControl()) |
return 0; |
- // find if this has a parent that is a label |
- for (Node* parentNode = node(); parentNode; parentNode = parentNode->parentNode()) { |
- if (isHTMLLabelElement(*parentNode)) |
- return toHTMLLabelElement(parentNode); |
- } |
- |
- return 0; |
+ // find if this has a ancestor that is a label |
+ return Traversal<HTMLLabelElement>::firstAncestorOrSelf(*node()); |
} |
void AXNodeObject::setFocused(bool on) |